Learn R Programming

LSPFP (version 1.0.3)

printSelectedPeptides: Only print peptides

Description

This function allows printing of different peptide plots after running wrapperLSPFP once.

Usage

printSelectedPeptides(path, fname, mysorteddf = NULL)

Arguments

path

Character vector giving the path to a data folder in the analysis directory.

fname

Character vector containing the name of the new file.

mysorteddf

A data.frame that can be a sorted and/or shortened data.frame of the feature_table from path.

Value

A PDF file named like fname in the analysis directory path. Returns TRUE if the printing was successful and FALSE if not.

Details

This function offers the possibility to print more selectively peptide plots after wrapperLSPFP was applied. To get a smaller plot, it is necessary to commit an existing anlaysis directory from the AnalysisData directory. The new file is named like fname and stored in the specified directory path. If a smaller dataset should be printed, a row wise sorted or shortened feature_table is to be used as basis for printing but no columns should be removed. This new data.frame (mysorteddf) will be processed for printing.

Examples

Run this code
# NOT RUN {
# }
# NOT RUN {
#To run this example you need to run the example from wrapperLSPFP

path <- paste0(getwd(),"/AnalysisData/Test_Mouse")
test <- read.csv(paste0(path, "/feature_table.csv"))


#Rows can be deleted or sorted but columns should not be removed
#Print the first 25 rows
myprint <- test[1:25,]
#Sort by accession
myprint2 <- test[sort(test$Accession), ]

printSelectedPeptides(path, "newfeaturetable", mysorteddf = myprint)

# }
# NOT RUN {
# }

Run the code above in your browser using DataLab