# NOT RUN {
# }
# NOT RUN {
#To run this example you need to run the example from wrapperLSPFP
path <- paste0(getwd(),"/AnalysisData/Test_Mouse")
test <- read.csv(paste0(path, "/feature_table.csv"))
#Rows can be deleted or sorted but columns should not be removed
#Print the first 25 rows
myprint <- test[1:25,]
#Sort by accession
myprint2 <- test[sort(test$Accession), ]
printSelectedPeptides(path, "newfeaturetable", mysorteddf = myprint)
# }
# NOT RUN {
# }
Run the code above in your browser using DataLab